#
# gtkui.py
#
# Copyright (C) 2009 Szentandrasi Istvan <szentandrasii@gmail.com>
#
# Basic plugin template created by:
# Copyright (C) 2008 Martijn Voncken <mvoncken@gmail.com>
# Copyright (C) 2007-2009 Andrew Resch <andrewresch@gmail.com>
# Copyright (C) 2009 Damien Churchill <damoxc@gmail.com>
#
# Deluge is free software.
#
# You may redistribute it and/or modify it under the terms of the
# GNU General Public License, as published by the Free Software
# Foundation; either version 3 of the License, or (at your option)
# any later version.
#
# deluge is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with deluge.    If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA  02110-1301, USA.
#
#    In addition, as a special exception, the copyright holders give
#    permission to link the code of portions of this program with the OpenSSL
#    library.
#    You must obey the GNU General Public License in all respects for all of
#    the code used other than OpenSSL. If you modify file(s) with this
#    exception, you may extend this exception to your version of the file(s),
#    but you are not obligated to do so. If you do not wish to do so, delete
#    this exception statement from your version. If you delete this exception
#    statement from all source files in the program, then also delete it here.
#
from __future__ import unicode_literals

from gi.repository import Gtk

import logging
log = logging.getLogger(__name__)
from deluge.ui.client import client
from deluge.plugins.pluginbase import Gtk3PluginBase
import deluge.component as component
import deluge.common

from .common import get_resource

class Gtk3UI(Gtk3PluginBase):
    def enable(self):
        self.builder = Gtk.Builder.new_from_file(get_resource("config.ui"))

        component.get("Preferences").add_page("TotalTraffic", self.builder.get_object("prefs_box"))
        component.get("PluginManager").register_hook("on_apply_prefs", self.on_apply_prefs)
        component.get("PluginManager").register_hook("on_show_prefs", self.on_show_prefs)
        
        self.status_item = component.get("StatusBar").add_item(
                image = get_resource("totaltraffic16.png"),
                text="",
                callback=self._on_status_item_clicked,
                tooltip="Session Downloaded(Total Down)/Session uploaded(Total up)")
        
        self.builder.get_object("reset").connect('clicked', self._reset_counters)

    def _reset_counters(self, widget, data=None):
        client.totaltraffic.reset_timers()

    def _on_status_item_clicked(self, *args, **kw):
        self.update()

    def disable(self):
        component.get("Preferences").remove_page("TotalTraffic")
        component.get("PluginManager").deregister_hook("on_apply_prefs", self.on_apply_prefs)
        component.get("PluginManager").deregister_hook("on_show_prefs", self.on_show_prefs)
        component.get("StatusBar").remove_item(self.status_item)
        del self.status_item

    def update(self):
        def cb_get_status(st):
            for key,value in st['traffic'].items():
                st[key] = deluge.common.fsize(value)
            if st["showTotal"]:
                self.status_item.set_text("S: %s/%s T: %s/%s" % (st["down"], st["up"], st["t_down"], st["t_up"]))
            else:
                self.status_item.set_text("%s/%s" % (st["down"], st["up"]))
        client.totaltraffic.get_status().addCallback(cb_get_status)

    def on_apply_prefs(self):
        log.debug("applying prefs for TotalTraffic")
        config = {
            "showPayload":self.builder.get_object("showPayload").get_active(),
            "showTotal":self.builder.get_object("showTotal").get_active()
        }
        client.totaltraffic.set_config(config)

    def on_show_prefs(self):
        client.totaltraffic.get_config().addCallback(self.cb_get_config)

    def cb_get_config(self, config):
        "callback for on show_prefs"
        self.builder.get_object("showPayload").set_active(config["showPayload"])
        self.builder.get_object("showTotal").set_active(config["showTotal"])

